@@ -9,6 +9,16 @@ pd.options.display.max_rows = 100
 
 # fetch metadata
 
+def get_places(urn=None):
+    params = locals()
+    r = requests.post(f"{BASE_URL}/places", json=params)
+    print(r.status_code)
+    return pd.DataFrame(r.json())
+
+def get_dispersion(urn=None, words=None, window=None, pr=None):
+    params = locals()
+    r = requests.post(f"{BASE_URL}/dispersion", json=params)
+    return pd.Series(r.json())
 
 def get_metadata(urns=None):
     """ Fetch metadata from a list of urns """
