@@ -1,4 +1,6 @@
 from .conc_coll import Concordance, Collocations, Counts
 from .corpus import Corpus, Corpus_from_identifiers, Corpus_from_identifiers as CorpusFromIdentifiers
+from .dispersion import Dispersion
 from .nbtokenizer import Tokens, tokenize
 from .chunking import Chunks
+from .geo_data import GeoData
