@@ -10,6 +10,7 @@ class Corpus():
             doctype=None,
             author=None,
             freetext=None,
+            fulltext=None,
             from_year=None,
             to_year=None,
             from_timestamp=None,
@@ -24,6 +25,7 @@ class Corpus():
             doctype,
             author,
             freetext,
+            fulltext,
             from_year,
             to_year,
             from_timestamp,
@@ -52,6 +54,8 @@ def urnlist(corpus):
         urnlist = list(corpus.corpus.urn)
     elif isinstance(corpus, DataFrame):
         urnlist = list(corpus.urn)
+    elif isinstance(corpus, list):
+        urnlist = corpus
     else:
         urnlist = []
     return urnlist
